package router

import (
	"fmt"
	gin2 "git.cestong.com.cn/cecf/cecf-golib/pkg/gin"
	"git.cestong.com.cn/cecf/hx-mobile-server-api/cmd/server/controller"
	"github.com/gin-gonic/gin"
	jwt "github.com/go-admin-team/go-admin-core/sdk/pkg/jwtauth"
	"github.com/go-playground/validator/v10"
	"gorm.io/gorm"
)

//BuildRegisterHXApi 注册汇学业务相关路由
func BuildRegisterHXApi(db *gorm.DB, reqValidator *validator.Validate, templateFilePath string) func(*gin.RouterGroup, *jwt.GinJWTMiddleware) {
	return func(r *gin.RouterGroup, authMid *jwt.GinJWTMiddleware) {
		deptCtl := controller.NewDeptController(db, reqValidator)
		deptGroup := r.Group("/departments")
		{

			deptGroup.POST(fmt.Sprintf("/:%s/children", controller.ParentDeptIDPath), deptCtl.Add)
			deptGroup.GET("", deptCtl.List)
			deptGroup.POST(fmt.Sprintf("/:%s/children/batch", controller.ParentDeptIDPath), deptCtl.BatchAdd)
			deptGroup.PUT(fmt.Sprintf("/:%s", controller.DeptIDPath), deptCtl.Update)
			deptGroup.DELETE(fmt.Sprintf("/:%s", controller.DeptIDPath), deptCtl.Delete)
			deptGroup.GET("/employees", deptCtl.ListUserOfDepartments)
			deptGroup.GET("/employees/recursive", deptCtl.ListUserOfDepartmentsRecursive)
		}

		occCtl := controller.NewOccupationController(db, reqValidator)
		occGroup := r.Group("/occupations")
		{
			occGroup.GET("", occCtl.List)
			occGroup.POST("/batch", occCtl.BatchAdd)
			occGroup.GET(fmt.Sprintf("/:%s/employees", controller.OccupationIDPath), occCtl.ListUser)
			//occGroup.POST(fmt.Sprintf("/:%s/employees", controller.OccupationIDPath), occCtl.BatchLinkToOccupationUsers)
			occGroup.DELETE(fmt.Sprintf("/:%s", controller.OccupationIDPath), occCtl.Delete)
			occGroup.DELETE("/batch", occCtl.BatchDelete)
			occGroup.PUT(fmt.Sprintf("/:%s", controller.OccupationIDPath), occCtl.Update)
		}

		employeeController := controller.NewEmployeeController(db, reqValidator, templateFilePath)
		employeeGroup := r.Group("/employees")
		{
			employeeGroup.GET("", employeeController.List)
			employeeGroup.POST("/batch", employeeController.BatchAdd)
			employeeGroup.GET("/batch/template", employeeController.GetBatchAddTemplateFile)
			employeeGroup.POST("/batch/import", employeeController.BatchAddByImport)
			employeeGroup.DELETE(fmt.Sprintf("/:%s", controller.EmployeeIDPath), employeeController.Delete)
			employeeGroup.PUT(fmt.Sprintf("/:%s", controller.EmployeeIDPath), employeeController.Update)
			employeeGroup.DELETE("/batch", employeeController.BatchDelete)
			employeeGroup.POST("/tag/batch", employeeController.BatchTagWithDepartmentAndOccupation)
			employeeGroup.GET(fmt.Sprintf("/:%s", controller.EmployeeIDPath), employeeController.Get)
		}

		courseController := controller.NewCourseController(db, reqValidator)
		courseGroup := r.Group("/course")
		{
			courseGroup.GET("/list", courseController.List)
			courseGroup.GET("/list/searchByCategory", courseController.CourseSearchByCategory)
			courseGroup.GET("/list/searchByTitle", courseController.ListByLikeTitle)
			// courseGroup.POST("/create", courseController.CreateCourse)
			// courseGroup.PUT("/edit", courseController.EditCourse)
			courseGroup.PUT("/edit_column", courseController.EditColumnStatus) // 推荐、发布、删除
		}

		categoryController := controller.NewCategoryController(db, reqValidator)
		categoryGroup := r.Group("/category")
		{
			categoryGroup.GET("/list", categoryController.List)
			categoryGroup.GET("/listByLevel", categoryController.ListByLevel)
		}

		kgUserController := controller.NewKGUserController(db, reqValidator)
		kgUseryGroup := r.Group("/kg_user")
		{
			kgUseryGroup.GET("/list", kgUserController.GetKgUser)
		}

		scheduleController := controller.NewScheduleController(db, reqValidator)
		scheduleGroup := r.Group("/schedule")
		{
			scheduleGroup.GET("/list", gin2.HandlerWrapper(scheduleController.List))
			scheduleGroup.PUT("/:scheduleID", gin2.HandlerWrapper(scheduleController.Update))
			scheduleGroup.DELETE("/batch", gin2.HandlerWrapper(scheduleController.DeleteBatch))
			scheduleGroup.POST("", gin2.HandlerWrapper(scheduleController.Create))
			scheduleGroup.GET("/:scheduleID", gin2.HandlerWrapper(scheduleController.Get))
			scheduleGroup.GET("/:scheduleID/copy/template", gin2.HandlerWrapper(scheduleController.GetCopyTemplate))
		}
		learningTaskController := controller.NewLearningTaskController(db, reqValidator)
		learningTaskGroup := r.Group("/learningtask")
		{
			learningTaskGroup.GET("/list", gin2.HandlerWrapper(learningTaskController.List))
			learningTaskGroup.GET("/:learningTaskID", gin2.HandlerWrapper(learningTaskController.Get))
			learningTaskGroup.POST("", gin2.HandlerWrapper(learningTaskController.Create))
			learningTaskGroup.PUT("/:learningTaskID", gin2.HandlerWrapper(learningTaskController.Update))
		}

	}
}
